==> resin-3.1.13-src.tar.gz: resin-3.1.13/modules/resin/src/com/caucho/ejb/cfg/RemoveMethod.java <==
/*
 * Copyright (c) 1998-2008 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free SoftwareFoundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Rodrigo Westrupp
 */

package com.caucho.ejb.cfg;

import com.caucho.config.ConfigException;
import com.caucho.util.L10N;
import com.caucho.ejb.gen.*;

import java.lang.reflect.*;

/**
 * Configuration for remove-method.
 */
public class RemoveMethod {
  private static final L10N L = new L10N(RemoveMethod.class);

  private BeanMethod _beanMethod;
  private boolean _retainIfException;

  public RemoveMethod()
  {
  }

  public BeanMethod getBeanMethod()
  {
    return _beanMethod;
  }

  public boolean isRetainIfException()
  {
    return _retainIfException;
  }

  public void setBeanMethod(BeanMethod beanMethod)
  {
    _beanMethod = beanMethod;
  }

  public void setRetainIfException(boolean retainIfException)
  {
    _retainIfException = retainIfException;
  }

  public boolean isMatch(Method method)
  {
    return _beanMethod.isMatch(method);
  }

  /**
   * Configures the bean with the override values
   */
  public void configure(BeanGenerator bean)
  {
    for (View view : bean.getViews()) {
      // XXX: check for type
      
      for (BusinessMethodGenerator bizMethod : view.getMethods()) {
	Method apiMethod = bizMethod.getApiMethod();
	
	if (_beanMethod.isMatch(apiMethod)) {
	  bizMethod.setRemove(true);
	  bizMethod.setRemoveRetainIfException(_retainIfException);
	}
      }
    }
  }
}

==> resin-4.0.65-src.tar.gz: resin-4.0.65/modules/resin/src/com/caucho/ejb/cfg/RemoveMethod.java <==
/*
 * Copyright (c) 1998-2018 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free SoftwareFoundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Rodrigo Westrupp
 */

package com.caucho.ejb.cfg;

import java.lang.reflect.Method;

import javax.annotation.PostConstruct;
import javax.enterprise.inject.spi.AnnotatedMethod;

import com.caucho.config.gen.BeanGenerator;
import com.caucho.config.reflect.AnnotatedMethodImpl;

/**
 * Configuration for remove-method.
 */
public class RemoveMethod<X> extends EjbMethodPattern<X> {
  private BeanMethod _beanMethod;
  private boolean _retainIfException;

  public RemoveMethod()
  {
  }

  public BeanMethod getBeanMethod()
  {
    return _beanMethod;
  }

  public boolean isRetainIfException()
  {
    return _retainIfException;
  }

  public void setBeanMethod(BeanMethod beanMethod)
  {
    _beanMethod = beanMethod;
  }

  public void setRetainIfException(boolean retainIfException)
  {
    _retainIfException = retainIfException;
  }

  @PostConstruct
  public void init()
  {
    setSignature(_beanMethod.getSignature());
  }
  
  @Override
  public boolean isMatch(AnnotatedMethod<?> method)
  {
    return _beanMethod.isMatch(method);
  }

  /**
   * Configures the bean with the override values
   */
  @Override
  public void configure(AnnotatedMethod<?> method)
  {
    if (isMatch(method)) {
      AnnotatedMethodImpl<?> methodImpl = (AnnotatedMethodImpl<?>) method;
      
      methodImpl.addAnnotation(new RemoveLiteral());
    }
  }
}
